import { Include, UnitResponse, UnitConfig } from "../types/common";
import { Customer } from "../types/customer";
import { Account } from "../types/account";
import { BaseResource } from "./baseResource";
import { AccountEndOfDay } from "../types/accountEndOfDay";
export declare class AccountsEndOfDay extends BaseResource {
    constructor(token: string, basePath: string, config?: UnitConfig);
    list(params?: AccountEndOfDayParams): Promise<UnitResponse<AccountEndOfDay[]> & Include<Customer> & Include<Account> & Include<Customer[]>>;
}
export interface AccountEndOfDayParams {
    /**
     * Maximum number of resources that will be returned. Maximum is 1000 resources. [See Pagination](https://developers.unit.co/#intro-pagination).
     * default: 100
     */
    limit?: number;
    /**
     * Number of resources to skip.  [See Pagination](https://developers.unit.co/#intro-pagination).
     * default: 0
     */
    offset?: number;
    /**
     * Optional. Filters the results by the specified customer id.
     * default: empty
     */
    customerId?: string;
    /**
     * Optional. Filters the results by the specified account id.
     * default: empty
     */
    accountId?: string;
    /**
     * Optional. Filters the account end-of-day balances before the specified date. e.g. 2021-06-01
     * default: empty
     */
    since?: string;
    /**
     * Optional. Filters the account end-of-day balances after the specified date. e.g. 2021-07-01
     * default: empty
     */
    until?: string;
}
