"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Authorizations = void 0;
const baseResource_1 = require("./baseResource");
class Authorizations extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/authorizations", config);
    }
    async get(id, includeNonAuthorized = false) {
        const parameters = {
            ...(includeNonAuthorized && { "filter[includeNonAuthorized]": includeNonAuthorized }),
        };
        return this.httpGet(`/${id}`, { params: parameters });
    }
    async find(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.cardId) && { "filter[cardId]": params.cardId }),
            ...((params === null || params === void 0 ? void 0 : params.since) && { "filter[since]": params.since }),
            ...((params === null || params === void 0 ? void 0 : params.until) && { "filter[until]": params.until }),
            ...((params === null || params === void 0 ? void 0 : params.includeNonAuthorized) && { "filter[includeNonAuthorized]": params.includeNonAuthorized }),
            ...((params === null || params === void 0 ? void 0 : params.sort) && { "sort": params.sort }),
            ...((params === null || params === void 0 ? void 0 : params.toAmount) && { "filter[toAmount]": params.toAmount }),
            ...((params === null || params === void 0 ? void 0 : params.fromAmount) && { "filter[fromAmount]": params.fromAmount }),
            ...((params === null || params === void 0 ? void 0 : params.status) && { "filter[status]": params.status }),
            ...params
        };
        if (params === null || params === void 0 ? void 0 : params.merchantCategoryCode)
            params.merchantCategoryCode.forEach((mcc, idx) => {
                parameters[`filter[merchantCategoryCode][${idx}]`] = mcc;
            });
        return this.httpGet("", { params: parameters });
    }
    async list(params) {
        return this.find(params);
    }
}
exports.Authorizations = Authorizations;
