"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AuthorizationRequests = void 0;
const baseResource_1 = require("./baseResource");
class AuthorizationRequests extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/authorization-requests", config);
    }
    async get(id) {
        return this.httpGet(`/${id}`);
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.toAmount) && { "filter[toAmount]": params.toAmount }),
            ...((params === null || params === void 0 ? void 0 : params.fromAmount) && { "filter[fromAmount]": params.fromAmount })
        };
        if (params === null || params === void 0 ? void 0 : params.merchantCategoryCode)
            params.merchantCategoryCode.forEach((mcc, idx) => {
                parameters[`filter[merchantCategoryCode][${idx}]`] = mcc;
            });
        return this.httpGet("", { params: parameters });
    }
    async approve(request) {
        const path = `/${request.id}/approve`;
        const data = {
            type: "approveAuthorizationRequest",
            attributes: {
                amount: request.amount,
                fundingAccount: request.fundingAccount,
                tags: request.tags
            }
        };
        return await this.httpPost(path, { data });
    }
    async decline(request) {
        const path = `/${request.id}/decline`;
        const data = {
            type: "declineAuthorizationRequest",
            attributes: {
                reason: request.reason
            }
        };
        return await this.httpPost(path, { data });
    }
}
exports.AuthorizationRequests = AuthorizationRequests;
