"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Payments = void 0;
const baseResource_1 = require("./baseResource");
class Payments extends baseResource_1.BaseResource {
    constructor(token, basePath, config) {
        super(token, basePath + "/payments", config);
    }
    async create(request) {
        return this.httpPost("", { data: request });
    }
    async createBulk(request) {
        return this.httpPost("/bulk", { data: request });
    }
    async update(id, request) {
        return this.httpPatch(`/${id}`, { data: request });
    }
    async cancel(id) {
        return this.httpPost(`/${id}/cancel`);
    }
    /**
     * Optional. A comma-separated list of related resources to include in the response.
     * Related resources include: customer, account, transaction. See Getting Related Resources
     */
    async get(id, include) {
        const params = { ...(include && { include }) };
        return this.httpGet(`/${id}`, { params });
    }
    async list(params) {
        const parameters = {
            "page[limit]": ((params === null || params === void 0 ? void 0 : params.limit) ? params.limit : 100),
            "page[offset]": ((params === null || params === void 0 ? void 0 : params.offset) ? params.offset : 0),
            ...((params === null || params === void 0 ? void 0 : params.accountId) && { "filter[accountId]": params.accountId }),
            ...((params === null || params === void 0 ? void 0 : params.customerId) && { "filter[customerId]": params.customerId }),
            ...((params === null || params === void 0 ? void 0 : params.tags) && { "filter[tags]": params.tags }),
            ...((params === null || params === void 0 ? void 0 : params.since) && { "filter[since]": params.since }),
            ...((params === null || params === void 0 ? void 0 : params.until) && { "filter[until]": params.until }),
            ...((params === null || params === void 0 ? void 0 : params.counterpartyAccountId) && { "filter[counterpartyAccountId]": params.counterpartyAccountId }),
            ...((params === null || params === void 0 ? void 0 : params.fromAmount) && { "filter[fromAmount]": params.fromAmount }),
            ...((params === null || params === void 0 ? void 0 : params.toAmount) && { "filter[toAmount]": params.toAmount }),
            "sort": (params === null || params === void 0 ? void 0 : params.sort) ? params.sort : "-createdAt",
            "include": (params === null || params === void 0 ? void 0 : params.include) ? params.include : ""
        };
        if (params === null || params === void 0 ? void 0 : params.type)
            params.type.forEach((t, idx) => {
                parameters[`filter[type][${idx}]`] = t;
            });
        if (params === null || params === void 0 ? void 0 : params.status)
            params.status.forEach((s, idx) => {
                parameters[`filter[status][${idx}]`] = s;
            });
        if (params === null || params === void 0 ? void 0 : params.direction)
            params.direction.forEach((d, idx) => {
                parameters[`filter[direction][${idx}]`] = d;
            });
        return this.httpGet("", { params: parameters });
    }
}
exports.Payments = Payments;
